caellion-python-commons: caellion.pycommons.encryption Namespace Reference

caellion-python-commons

Namespaces
caellion.pycommons.encryption Namespace Reference

This package provides facilities related to encryption and decryption (but not hashing) More...

## Namespaces
| tripledes
| This module provides utilities related to or using 3DES symmetric encryption algorithm.

## Detailed Description

This package provides facilities related to encryption and decryption (but not hashing)